@@ -488,6 +488,14 @@ def expand(f, single_account, parameter_override_file, parameter_override_forced
     params = dict(single_account=single_account)
     if parameter_override_forced or misc_commands.is_a_parameter_override_execution():
         overrides = dict(**yaml.safe_load(parameter_override_file.read()))
+        if overrides.get("subset"):
+            subset = overrides.get("subset")
+            overrides = dict(
+                section=subset.get("section"),
+                item=subset.get("name"),
+                include_dependencies=subset.get("include_dependencies"),
+                include_reverse_dependencies=subset.get("include_reverse_dependencies"),
+            )
         params.update(
             dict(single_account=overrides.get("single_account"), subset=overrides,)
         )
