@@ -191,6 +191,8 @@ SECTION_SINGULAR_TO_PLURAL = {
     ASSERTION: ASSERTIONS,
     APP: APPS,
     WORKSPACE: WORKSPACES,
+    SIMULATE_POLICY: SIMULATE_POLICIES,
+    SERVICE_CONTROL_POLICY: SERVICE_CONTROL_POLICIES,
 }
 
 CODEBUILD_DEFAULT_IMAGE = "aws/codebuild/standard:4.0"
